@@ -114,7 +114,8 @@ def tasks_sample():
         Task("g1", None, doc="g1 doc string"),
         Task("g1.a", [""], doc="g1.a doc string", is_subtask=True),
         Task("g1.b", [""], doc="g1.b doc string", is_subtask=True),
-        Task("t3", [""], doc="t3 doc string")]
+        Task("t3", [""], doc="t3 doc string", task_dep=["t1"])
+        ]
     tasks_sample[2].task_dep = ['g1.a', 'g1.b']
     return tasks_sample
 
